@@ -29,7 +29,6 @@ let ($) f x = f x
 
 let base = ref "."
 let config_dir = ref "config"
-let global_config = ref (FilePath.concat !config_dir "global.conf")
 let lock = ref "ben.lock"
 let clean = ref true
 let tconfig = ref None
@@ -46,13 +45,13 @@ let eval x =
     (Package.of_assoc `source Benl_core.StringMap.empty)
     (Query.of_expr x)
 
-let read_global_config () =
-  if Sys.file_exists !global_config then begin
-    let config = Benl_utils.parse_config_file !global_config in
+let read_global_config file =
+  Printf.eprintf "read_global_config %s\n%!" file;
+  if Sys.file_exists file then begin
+    let config = Benl_utils.parse_config_file file in
     StringMap.iter (fun key value -> match (key, value) with
         | "architectures", archs ->
-          Benl_base.debian_architectures := to_string_l "architectures" archs;
-          Benl_clflags.architectures := to_string_l "architectures" archs
+          Benl_base.debian_architectures := to_string_l "architectures" archs
         | "ignored", archs ->
           Benl_base.ignored_architectures := to_string_l "ignored" archs
         | "suite", (EString suite) ->
@@ -100,8 +99,8 @@ let lockf () =
 let spec = Arg.align [
   "--config-dir" , Arg.Set_string config_dir, " Specify tracker's global configuration directory";
   "-cd"          , Arg.Set_string config_dir, " ";
-  "--global-conf", Arg.Set_string global_config, " Specify tracker's global configuration file";
-  "-g"           , Arg.Set_string global_config, " ";
+  "--global-conf", Arg.String read_global_config, " Specify tracker's global configuration file";
+  "-g"           , Arg.String read_global_config, " ";
   "--transition" , Arg.String (fun t -> tconfig := Some t), " Specify selected transition";
   "-t"           , Arg.String (fun t -> tconfig := Some t), " ";
   "--update"     , Arg.Set Benl_clflags.update, " Do update the cache file";
@@ -464,18 +463,17 @@ let tracker template profiles =
   with exn ->
     Benl_error.error_exn "Failed to generate index.html" exn
 
-let () = at_exit (fun () ->
-  try
-    rm [lockf ()]
-  with _ -> ()
-)
-
 let main () =
-  let () = read_global_config () in
   let lockf = lockf () in
   if test Exists lockf then
     eprintf "Please wait until %s is removed!\n" lockf
   else
+    let () = at_exit (fun () ->
+      try
+        rm [lockf]
+      with _ -> ()
+      )
+    in
     try
       let lockf_b = Filename.dirname lockf in
       let () = if test Exists lockf_b then
